@@ -664,7 +664,7 @@ class _ExtractUpdates:
         existing_schema_policy: bool | Literal["ignore"] = True,
     ):
         new_tools: list = [PatchDoc]
-        tool_choice = PatchDoc.__name__ if not enable_deletes else "any"
+        tool_choice = "PatchDoc" if not enable_deletes else "any"
         if enable_inserts:  # Also let the LLM know that we can extract NEW schemas.
             tools_ = [
                 schema
@@ -802,7 +802,7 @@ class _ExtractUpdates:
                             )
                         )
                         updated_docs[tc["id"]] = str(json_doc_id)
-                    except (jsonpatch.JsonPatchConflict, JSONDecodeError) as e:
+                    except Exception as e:
                         logger.error(f"Could not apply patch: {e}")
                         if rt:
                             rt.error = f"Could not apply patch: {repr(e)}"
@@ -1052,7 +1052,7 @@ class _Patch:
 
     async def ainvoke(
         self, state: ExtendedExtractState, config: RunnableConfig
-    ) -> dict:
+    ) -> Command[Literal["sync", "__end__"]]:
         """Generate a JSONPatch to correct the validation error and heal the tool call.
 
         Assumptions:
@@ -1075,7 +1075,9 @@ class _Patch:
             goto=("sync",),
         )
 
-    def invoke(self, state: ExtendedExtractState, config: RunnableConfig) -> dict:
+    def invoke(
+        self, state: ExtendedExtractState, config: RunnableConfig
+    ) -> Command[Literal["sync", "__end__"]]:
         try:
             msg = self.bound.invoke(state.messages, config)
         except Exception:
@@ -1448,7 +1450,7 @@ def _get_message_op(
                                     },
                                 }
                             )
-                        except (jsonpatch.JsonPatchConflict, JSONDecodeError) as e:
+                        except Exception as e:
                             if rt:
                                 rt.error = f"Could not apply patch: {repr(e)}"
                             logger.error(f"Could not apply patch: {repr(e)}")
